
|version|, |today|

.. include:: ../README.rst




Complete documentation including User and Developer Guides
##########################################################

.. toctree::
    :maxdepth: 2
    :numbered:

    installation
    user_guide
    tutorial
    developer_guide
    benchmarking
    auto_examples/index
    references
    formats
    glossary
    faqs
    bibliography
    ChangeLog.rst




